# `relationalai.Producer.__rmod__()`

```python
relationalai.Producer.__rmod__(other: Any) -> Expression
```

Returns an [`Expression`](../Expression.md) object representing the remainder of dividing `other` by the values of the `Producer`.
`.__rmod__()` is implemented so that you may use a non-`Producer` object as the left operand.

## See Also

[`Producer.__mod__()`](./mod__.md)
